@@ -10,8 +10,8 @@ See the cf-plot home page http://ajheaps.github.io/cf-plot for a gallery of plot
 '''
 
 __author__ = 'Andy Heaps - andy.heaps@ncas.ac.uk'
-__date__ = '13th April 2021'
-__version__ = '3.1.0'
+__date__ = '20th May 2021'
+__version__ = '3.1.3'
 
 from .cfplot import *
 
